@@ -15,10 +15,8 @@
 
 #include <dbus/dbus-glib.h>
 
-#include <telepathy-glib/dbus.h>
-#include <telepathy-glib/errors.h>
+#include <telepathy-glib/telepathy-glib.h>
 #include <telepathy-glib/handle-repo-dynamic.h>
-#include <telepathy-glib/interfaces.h>
 
 #include "room-manager.h"
 
