@@ -15,10 +15,7 @@
 
 #include <dbus/dbus-glib.h>
 
-#include <telepathy-glib/base-connection.h>
-#include <telepathy-glib/dbus.h>
-#include <telepathy-glib/errors.h>
-#include <telepathy-glib/interfaces.h>
+#include <telepathy-glib/telepathy-glib.h>
 
 #include "contact-list.h"
 
@@ -827,14 +824,14 @@ ensure_group (ExampleContactListManager *self,
 }
 
 static const gchar * const fixed_properties[] = {
-    TP_IFACE_CHANNEL ".ChannelType",
-    TP_IFACE_CHANNEL ".TargetHandleType",
+    TP_PROP_CHANNEL_CHANNEL_TYPE,
+    TP_PROP_CHANNEL_TARGET_HANDLE_TYPE,
     NULL
 };
 
 static const gchar * const allowed_properties[] = {
-    TP_IFACE_CHANNEL ".TargetHandle",
-    TP_IFACE_CHANNEL ".TargetID",
+    TP_PROP_CHANNEL_TARGET_HANDLE,
+    TP_PROP_CHANNEL_TARGET_ID,
     NULL
 };
 
@@ -843,17 +840,15 @@ example_contact_list_manager_foreach_channel_class (TpChannelManager *manager,
     TpChannelManagerChannelClassFunc func,
     gpointer user_data)
 {
-    GHashTable *table = g_hash_table_new_full (g_str_hash, g_str_equal,
-        NULL, (GDestroyNotify) tp_g_value_slice_free);
+    GHashTable *table = tp_asv_new (
+        TP_PROP_CHANNEL_CHANNEL_TYPE,
+            G_TYPE_STRING, TP_IFACE_CHANNEL_TYPE_CONTACT_LIST,
+        TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, G_TYPE_UINT, TP_HANDLE_TYPE_LIST,
+        NULL);
 
-    g_hash_table_insert (table, TP_IFACE_CHANNEL ".ChannelType",
-        tp_g_value_slice_new_static_string (
-          TP_IFACE_CHANNEL_TYPE_CONTACT_LIST));
-    g_hash_table_insert (table, TP_IFACE_CHANNEL ".TargetHandleType",
-        tp_g_value_slice_new_uint (TP_HANDLE_TYPE_LIST));
     func (manager, table, allowed_properties, user_data);
 
-    g_hash_table_insert (table, TP_IFACE_CHANNEL ".TargetHandleType",
+    g_hash_table_insert (table, TP_PROP_CHANNEL_TARGET_HANDLE_TYPE,
         tp_g_value_slice_new_uint (TP_HANDLE_TYPE_GROUP));
     func (manager, table, allowed_properties, user_data);
 
@@ -872,14 +867,14 @@ example_contact_list_manager_request (ExampleContactListManager *self,
   GError *error = NULL;
 
   if (tp_strdiff (tp_asv_get_string (request_properties,
-          TP_IFACE_CHANNEL ".ChannelType"),
+          TP_PROP_CHANNEL_CHANNEL_TYPE),
       TP_IFACE_CHANNEL_TYPE_CONTACT_LIST))
     {
       return FALSE;
     }
 
   handle_type = tp_asv_get_uint32 (request_properties,
-      TP_IFACE_CHANNEL ".TargetHandleType", NULL);
+      TP_PROP_CHANNEL_TARGET_HANDLE_TYPE, NULL);
 
   if (handle_type != TP_HANDLE_TYPE_LIST &&
       handle_type != TP_HANDLE_TYPE_GROUP)
@@ -888,7 +883,7 @@ example_contact_list_manager_request (ExampleContactListManager *self,
     }
 
   handle = tp_asv_get_uint32 (request_properties,
-      TP_IFACE_CHANNEL ".TargetHandle", NULL);
+      TP_PROP_CHANNEL_TARGET_HANDLE, NULL);
   g_assert (handle != 0);
 
   if (tp_channel_manager_asv_has_unknown_properties (request_properties,
@@ -912,7 +907,7 @@ example_contact_list_manager_request (ExampleContactListManager *self,
 
   if (chan == NULL)
     {
-      chan = new_channel (self, handle_type, handle, request_token);
+      new_channel (self, handle_type, handle, request_token);
     }
   else if (require_new)
     {
