@@ -1,8 +1,8 @@
 /*
  * dbus.h - Header for D-Bus utilities
  *
- * Copyright (C) 2005-2007 Collabora Ltd. <http://www.collabora.co.uk/>
- * Copyright (C) 2005-2007 Nokia Corporation
+ * Copyright (C) 2005-2009 Collabora Ltd. <http://www.collabora.co.uk/>
+ * Copyright (C) 2005-2009 Nokia Corporation
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -21,50 +21,15 @@
 
 #ifndef __TELEPATHY_DBUS_H__
 #define __TELEPATHY_DBUS_H__
+#define __TP_IN_DBUS_H__
 
-#include <telepathy-glib/proxy.h>
+#include <telepathy-glib/dbus-daemon.h>
 
 G_BEGIN_DECLS
 
 void tp_dbus_g_method_return_not_implemented (DBusGMethodInvocation *context);
 DBusGConnection * tp_get_bus (void);
 
-/* TpDBusDaemon is typedef'd in proxy.h */
-typedef struct _TpDBusDaemonPrivate TpDBusDaemonPrivate;
-typedef struct _TpDBusDaemonClass TpDBusDaemonClass;
-GType tp_dbus_daemon_get_type (void);
-
-#define TP_TYPE_DBUS_DAEMON \
-  (tp_dbus_daemon_get_type ())
-#define TP_DBUS_DAEMON(obj) \
-  (G_TYPE_CHECK_INSTANCE_CAST((obj), TP_TYPE_DBUS_DAEMON, \
-                              TpDBusDaemon))
-#define TP_DBUS_DAEMON_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST((klass), TP_TYPE_DBUS_DAEMON, \
-                           TpDBusDaemonClass))
-#define TP_IS_DBUS_DAEMON(obj) \
-  (G_TYPE_CHECK_INSTANCE_TYPE((obj), TP_TYPE_DBUS_DAEMON))
-#define TP_IS_DBUS_DAEMON_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_TYPE((klass), TP_TYPE_DBUS_DAEMON))
-#define TP_DBUS_DAEMON_GET_CLASS(obj) \
-  (G_TYPE_INSTANCE_GET_CLASS ((obj), TP_TYPE_DBUS_DAEMON, \
-                              TpDBusDaemonClass))
-
-TpDBusDaemon *tp_dbus_daemon_dup (GError **error);
-
-TpDBusDaemon *tp_dbus_daemon_new (DBusGConnection *connection);
-
-typedef void (*TpDBusDaemonNameOwnerChangedCb) (TpDBusDaemon *bus_daemon,
-    const gchar *name, const gchar *new_owner, gpointer user_data);
-
-void tp_dbus_daemon_watch_name_owner (TpDBusDaemon *self,
-    const gchar *name, TpDBusDaemonNameOwnerChangedCb callback,
-    gpointer user_data, GDestroyNotify destroy);
-
-gboolean tp_dbus_daemon_cancel_name_owner_watch (TpDBusDaemon *self,
-    const gchar *name, TpDBusDaemonNameOwnerChangedCb callback,
-    gconstpointer user_data);
-
 typedef enum
 {
   TP_DBUS_NAME_TYPE_UNIQUE = 1,
@@ -88,11 +53,16 @@ gboolean tp_dbus_check_valid_member_name (const gchar *name,
 gboolean tp_dbus_check_valid_object_path (const gchar *path,
     GError **error);
 
-GValue *tp_g_value_slice_new_bytes (guint length, gconstpointer bytes);
-GValue *tp_g_value_slice_new_take_bytes (GArray *bytes);
-GValue *tp_g_value_slice_new_object_path (const gchar *path);
-GValue *tp_g_value_slice_new_static_object_path (const gchar *path);
-GValue *tp_g_value_slice_new_take_object_path (gchar *path);
+GValue *tp_g_value_slice_new_bytes (guint length, gconstpointer bytes)
+  G_GNUC_WARN_UNUSED_RESULT;
+GValue *tp_g_value_slice_new_take_bytes (GArray *bytes)
+  G_GNUC_WARN_UNUSED_RESULT;
+GValue *tp_g_value_slice_new_object_path (const gchar *path)
+  G_GNUC_WARN_UNUSED_RESULT;
+GValue *tp_g_value_slice_new_static_object_path (const gchar *path)
+  G_GNUC_WARN_UNUSED_RESULT;
+GValue *tp_g_value_slice_new_take_object_path (gchar *path)
+  G_GNUC_WARN_UNUSED_RESULT;
 
 #define tp_asv_size(asv) _tp_asv_size_inline (asv)
 
@@ -104,7 +74,8 @@ _tp_asv_size_inline (const GHashTable *asv)
   return g_hash_table_size /* */ ((GHashTable *) asv);
 }
 
-GHashTable *tp_asv_new (const gchar *first_key, ...) G_GNUC_NULL_TERMINATED;
+GHashTable *tp_asv_new (const gchar *first_key, ...)
+  G_GNUC_NULL_TERMINATED G_GNUC_WARN_UNUSED_RESULT;
 gboolean tp_asv_get_boolean (const GHashTable *asv, const gchar *key,
     gboolean *valid);
 void tp_asv_set_boolean (GHashTable *asv, const gchar *key, gboolean value);
@@ -155,12 +126,11 @@ tp_asv_get_strv (const GHashTable *asv, const gchar *key);
 void tp_asv_set_strv (GHashTable *asv, const gchar *key, gchar **value);
 void tp_asv_dump (GHashTable *asv);
 
-G_END_DECLS
-
-#include <telepathy-glib/_gen/tp-cli-dbus-daemon.h>
-
 #ifndef TP_DISABLE_DEPRECATED
 DBusGProxy * tp_get_bus_proxy (void) G_GNUC_DEPRECATED;
 #endif
 
+G_END_DECLS
+
+#undef __TP_IN_DBUS_H__
 #endif /* __TELEPATHY_DBUS_H__ */
