@@ -1,6 +1,7 @@
 /*
  * gtypes.h - Specialized GTypes representing D-Bus structs etc.
- * Copyright (C) 2007 Collabora Ltd.
+ * Copyright (C) 2007 Collabora Ltd. <http://www.collabora.co.uk/>
+ * Copyright (C) 2007 Nokia Corporation
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,6 +27,10 @@ G_BEGIN_DECLS
 
 #include <telepathy-glib/_gen/gtypes.h>
 
+#define TP_ARRAY_TYPE_OBJECT_PATH_LIST (tp_type_dbus_array_of_o ())
+
+GType tp_type_dbus_array_of_o (void);
+
 GValue *tp_dbus_specialized_value_slice_new (GType type);
 
 G_END_DECLS
