@@ -564,6 +564,29 @@ test_complex_file_got_info (Test *test,
   g_assert_cmpstr (strv[0], ==, "");
   g_assert (strv[1] == NULL);
 
+  param = &protocol->params[19];
+  g_assert_cmpstr (param->name, ==, "true");
+  g_assert_cmpuint (param->flags, ==, TP_CONN_MGR_PARAM_FLAG_HAS_DEFAULT);
+  g_assert_cmpstr (param->dbus_signature, ==, "b");
+  g_assert (G_VALUE_HOLDS_BOOLEAN (&param->default_value));
+  g_assert_cmpint (g_value_get_boolean (&param->default_value), ==, TRUE);
+
+  param = &protocol->params[20];
+  g_assert_cmpstr (param->name, ==, "false");
+  g_assert_cmpuint (param->flags, ==, TP_CONN_MGR_PARAM_FLAG_HAS_DEFAULT);
+  g_assert_cmpstr (param->dbus_signature, ==, "b");
+  g_assert (G_VALUE_HOLDS_BOOLEAN (&param->default_value));
+  g_assert_cmpint (g_value_get_boolean (&param->default_value), ==, FALSE);
+
+  param = &protocol->params[21];
+  g_assert_cmpstr (param->name, ==, "y");
+  g_assert_cmpuint (param->flags, ==, TP_CONN_MGR_PARAM_FLAG_HAS_DEFAULT);
+  g_assert_cmpstr (param->dbus_signature, ==, "y");
+  g_assert (G_VALUE_HOLDS_UCHAR (&param->default_value));
+  g_assert_cmpint (g_value_get_uchar (&param->default_value), ==, 42);
+
+  param = &protocol->params[22];
+  g_assert (param->name == NULL);
 }
 
 static void
@@ -728,12 +751,20 @@ test_complex_file_ready (Test *test,
   g_free (name);
 }
 
+static gboolean
+idle_activate (gpointer cm)
+{
+  tp_connection_manager_activate (cm);
+  return FALSE;
+}
+
 static void
 test_dbus_ready (Test *test,
-                 gconstpointer data G_GNUC_UNUSED)
+                 gconstpointer data)
 {
   gchar *name;
   guint info_source;
+  const gboolean activate = GPOINTER_TO_INT (data);
 
   test->error = NULL;
   test->cm = tp_connection_manager_new (test->dbus,
@@ -743,7 +774,22 @@ test_dbus_ready (Test *test,
   g_assert (test->error == NULL);
   g_test_queue_unref (test->cm);
 
-  g_test_bug ("18291");
+  if (activate)
+    {
+      g_test_bug ("23524");
+
+      /* The bug being tested here was caused by ListProtocols being called
+       * twice on the same CM; this can be triggered by _activate()ing at
+       * exactly the wrong moment. But the wrong moment involves racing an
+       * idle. This triggered the assertion about 1/3 of the time on my laptop.
+       * --wjt
+       */
+      g_idle_add (idle_activate, test->cm);
+    }
+  else
+    {
+      g_test_bug ("18291");
+    }
 
   tp_connection_manager_call_when_ready (test->cm, ready_or_not,
       test, NULL, NULL);
@@ -839,7 +885,10 @@ main (int argc,
   g_test_add ("/cm/file", Test, NULL, setup, test_file_ready, teardown);
   g_test_add ("/cm/file (complex)", Test, NULL, setup,
       test_complex_file_ready, teardown);
-  g_test_add ("/cm/dbus", Test, NULL, setup, test_dbus_ready, teardown);
+  g_test_add ("/cm/dbus", Test, GINT_TO_POINTER (FALSE), setup,
+      test_dbus_ready, teardown);
+  g_test_add ("/cm/dbus-and-activate", Test, GINT_TO_POINTER (TRUE), setup,
+      test_dbus_ready, teardown);
 
   g_test_add ("/cm/list", Test, NULL, setup, test_list, teardown);
 
