@@ -23,7 +23,6 @@
 
 #define IDENTIFIER "them@example.org"
 
-static int fail = 0;
 static GMainLoop *mainloop;
 TestTextChannelGroup *service_chan;
 TpChannel *chan = NULL;
@@ -41,12 +40,6 @@ static TpHandle expected_actor;
 static TpChannelGroupChangeReason expected_reason;
 static diff_checker expected_diffs;
 
-static void
-myassert_failed (void)
-{
-  fail = 1;
-}
-
 static void
 expect_signals (const gchar *message,
                 TpHandle actor,
@@ -171,7 +164,7 @@ check_initial_properties (void)
 
   MYASSERT (tp_cli_dbus_properties_run_get_all (chan, -1,
       TP_IFACE_CHANNEL_INTERFACE_GROUP, &props, &error, NULL), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   members = tp_asv_get_boxed (props, "Members", DBUS_TYPE_G_UINT_ARRAY);
   MYASSERT (members != NULL, ": Members should be defined"); \
@@ -304,7 +297,7 @@ check_incoming_invitation (void)
         self_added_to_members);
     MYASSERT (tp_cli_channel_interface_group_run_add_members (chan, -1,
         contacts, "", &error, NULL), "");
-    MYASSERT_NO_ERROR (error);
+    test_assert_no_error (error);
     wait_for_outstanding_signals ();
     MYASSERT (!outstanding_signals (),
         ": MembersChanged and MembersChangedDetailed should have fired once");
@@ -412,13 +405,10 @@ in_the_desert (void)
     TpIntSet *add = tp_intset_new ();
     GHashTable *details = g_hash_table_new_full (g_str_hash, g_str_equal,
         NULL, (GDestroyNotify) tp_g_value_slice_free);
-    GValue *v;
 
     tp_intset_add (add, camel2);
 
-    v = tp_g_value_slice_new (G_TYPE_UINT);
-    g_value_set_uint (v, camel);
-    g_hash_table_insert (details, "actor", v);
+    g_hash_table_insert (details, "actor", tp_g_value_slice_new_uint (camel));
 
     expect_signals ("", camel, TP_CHANNEL_GROUP_CHANGE_REASON_NONE,
         camel2_added);
@@ -436,33 +426,24 @@ in_the_desert (void)
     TpIntSet *del = tp_intset_new ();
     GHashTable *details = g_hash_table_new_full (g_str_hash, g_str_equal,
         NULL, (GDestroyNotify) tp_g_value_slice_free);
-    GValue *v;
 
     tp_intset_add (del, camel);
 
-    v = tp_g_value_slice_new (G_TYPE_UINT);
-    g_value_set_uint (v, camel2);
-    g_hash_table_insert (details, "actor", v);
+    g_hash_table_insert (details, "actor", tp_g_value_slice_new_uint (camel2));
 
     /* It turns out that spitting was not included in the GroupChangeReason
      * enum.
      */
-    v = tp_g_value_slice_new (G_TYPE_STRING);
-    g_value_set_static_string (v, "le.mac.Spat");
-    g_hash_table_insert (details, "error", v);
-
-    v = tp_g_value_slice_new (G_TYPE_STRING);
-    g_value_set_static_string (v, "fluid");
-    g_hash_table_insert (details, "saliva-consistency", v);
+    g_hash_table_insert (details, "error",
+        tp_g_value_slice_new_static_string ("le.mac.Spat"));
+    g_hash_table_insert (details, "saliva-consistency",
+        tp_g_value_slice_new_static_string ("fluid"));
 
     /* Kicking is the closest we have to this .. unsavory act. */
-    v = tp_g_value_slice_new (G_TYPE_UINT);
-    g_value_set_uint (v, TP_CHANNEL_GROUP_CHANGE_REASON_KICKED);
-    g_hash_table_insert (details, "change-reason", v);
-
-    v = tp_g_value_slice_new (G_TYPE_STRING);
-    g_value_set_static_string (v, "*ptooey*");
-    g_hash_table_insert (details, "message", v);
+    g_hash_table_insert (details, "change-reason",
+        tp_g_value_slice_new_uint (TP_CHANNEL_GROUP_CHANGE_REASON_KICKED));
+    g_hash_table_insert (details, "message",
+        tp_g_value_slice_new_static_string ("*ptooey*"));
 
     /* Check that all the right information was extracted from the dict. */
     expect_signals ("*ptooey*", camel2,
@@ -512,7 +493,7 @@ test_group_mixin (void)
   GError *error = NULL;
 
   MYASSERT (tp_channel_run_until_ready (chan, &error, NULL), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   MYASSERT (tp_proxy_has_interface (chan, TP_IFACE_CHANNEL_INTERFACE_GROUP),
       "");
@@ -556,15 +537,15 @@ main (int argc,
 
   MYASSERT (tp_base_connection_register (service_conn_as_base, "simple",
         &name, &conn_path, &error), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   conn = tp_connection_new (dbus, name, conn_path, &error);
   MYASSERT (conn != NULL, "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   MYASSERT (tp_connection_run_until_ready (conn, TRUE, &error, NULL),
       "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   contact_repo = tp_base_connection_get_handles (service_conn_as_base,
       TP_HANDLE_TYPE_CONTACT);
@@ -583,19 +564,19 @@ main (int argc,
   mainloop = g_main_loop_new (NULL, FALSE);
 
   MYASSERT (tp_cli_connection_run_connect (conn, -1, &error, NULL), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   chan = tp_channel_new (conn, chan_path, NULL, TP_UNKNOWN_HANDLE_TYPE, 0,
       &error);
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   MYASSERT (tp_channel_run_until_ready (chan, &error, NULL), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   test_group_mixin ();
 
   MYASSERT (tp_cli_connection_run_disconnect (conn, -1, &error, NULL), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   /* clean up */
 
@@ -613,5 +594,5 @@ main (int argc,
   g_free (conn_path);
   g_free (chan_path);
 
-  return fail;
+  return 0;
 }
