@@ -20,14 +20,6 @@
 #include "tests/lib/myassert.h"
 #include "tests/lib/util.h"
 
-static int fail = 0;
-
-static void
-myassert_failed (void)
-{
-  fail = 1;
-}
-
 static guint received_count = 0;
 static guint last_received_id = 0;
 static guint last_received_sender = 0;
@@ -114,22 +106,22 @@ main (int argc,
 
   MYASSERT (tp_base_connection_register (service_conn_as_base, "example",
         &name, &conn_path, &error), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   conn = tp_connection_new (dbus, name, conn_path, &error);
   MYASSERT (conn != NULL, "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   MYASSERT (tp_connection_run_until_ready (conn, TRUE, &error, NULL),
       "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   contact_repo = tp_base_connection_get_handles (service_conn_as_base,
       TP_HANDLE_TYPE_CONTACT);
   MYASSERT (contact_repo != NULL, "");
 
   handle = tp_handle_ensure (contact_repo, "them@example.org", NULL, &error);
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   /* FIXME: exercise RequestChannel rather than just pasting on a channel */
 
@@ -144,10 +136,10 @@ main (int argc,
 
   chan = tp_channel_new (conn, chan_path, TP_IFACE_CHANNEL_TYPE_TEXT,
       TP_HANDLE_TYPE_CONTACT, handle, &error);
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   tp_channel_run_until_ready (chan, &error, NULL);
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   MYASSERT (tp_cli_channel_type_text_connect_to_received (chan, on_received,
       g_object_ref (contact_repo), g_object_unref, NULL, NULL) != NULL, "");
@@ -159,7 +151,7 @@ main (int argc,
   tp_cli_channel_type_text_run_send (chan, -1,
       TP_CHANNEL_TEXT_MESSAGE_TYPE_NORMAL, "Hello, world!",
       &error, NULL);
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   test_connection_run_until_dbus_queue_processed (conn);
   MYASSERT (sent_count == 1, ": %u != 1", sent_count);
@@ -181,7 +173,7 @@ main (int argc,
   tp_cli_channel_type_text_run_send (chan, -1,
       TP_CHANNEL_TEXT_MESSAGE_TYPE_ACTION, "drinks coffee",
       &error, NULL);
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   test_connection_run_until_dbus_queue_processed (conn);
   MYASSERT (sent_count == 1, ": %u != 1", sent_count);
@@ -204,7 +196,7 @@ main (int argc,
   tp_cli_channel_type_text_run_send (chan, -1,
       TP_CHANNEL_TEXT_MESSAGE_TYPE_NOTICE, "Printer on fire",
       &error, NULL);
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   test_connection_run_until_dbus_queue_processed (conn);
   MYASSERT (sent_count == 1, ": %u != 1", sent_count);
@@ -229,7 +221,7 @@ main (int argc,
 
       tp_cli_channel_type_text_run_list_pending_messages (chan, -1,
           FALSE, &messages, &error, NULL);
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
 
       g_print ("Freeing\n");
       g_boxed_free (TP_ARRAY_TYPE_PENDING_TEXT_MESSAGE_LIST, messages);
@@ -272,7 +264,7 @@ main (int argc,
 
       tp_cli_channel_type_text_run_acknowledge_pending_messages (chan, -1,
           ids, &error, NULL);
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
 
       g_array_free (ids, TRUE);
     }
@@ -285,7 +277,7 @@ main (int argc,
 
       tp_cli_channel_type_text_run_list_pending_messages (chan, -1,
           TRUE, &messages, &error, NULL);
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
 
       g_print ("Freeing\n");
       g_boxed_free (TP_ARRAY_TYPE_PENDING_TEXT_MESSAGE_LIST, messages);
@@ -297,7 +289,7 @@ main (int argc,
       gboolean dead;
 
       MYASSERT (tp_cli_channel_run_close (chan, -1, &error, NULL), "");
-      MYASSERT_NO_ERROR (error);
+      test_assert_no_error (error);
       MYASSERT (tp_proxy_get_invalidated (chan) != NULL, "");
 
       g_object_get (service_chan,
@@ -310,7 +302,7 @@ main (int argc,
   g_print ("\n\n==== End of tests ====\n");
 
   MYASSERT (tp_cli_connection_run_disconnect (conn, -1, &error, NULL), "");
-  MYASSERT_NO_ERROR (error);
+  test_assert_no_error (error);
 
   tp_handle_unref (contact_repo, handle);
   g_object_unref (chan);
@@ -327,5 +319,5 @@ main (int argc,
   g_free (last_sent_text);
   g_free (last_received_text);
 
-  return fail;
+  return 0;
 }
